package permissions.dispatcher.processor.data;

public final class Source {

    public static final String[] EMPTY = {};

    public static class OnePermissionActivity {
        public static final String[] ACTUAL = {
                "package permissions.dispatcher.sample;",
                "import android.Manifest;",
                "import android.app.Activity;",
                "import android.os.Bundle;",
                "import android.view.Menu;",
                "import android.view.MenuItem;",
                "import permissions.dispatcher.NeedsPermission;",
                "import permissions.dispatcher.RuntimePermissions;",
                "import permissions.dispatcher.ShowsRationale;",
                "@RuntimePermissions",
                "public class MainActivity extends Activity {",
                "@NeedsPermission(Manifest.permission.CAMERA)",
                "void showCamera() {",
                "}",
                "@ShowsRationale(Manifest.permission.CAMERA)",
                "void showRationaleForCamera() {",
                "}",
                "}"};

        public static final String[] EXPECT = {
                "package permissions.dispatcher.sample;",
                "\n",
                "import android.support.v4.app.ActivityCompat;",
                "import java.lang.String;",
                "import permissions.dispatcher.PermissionUtils;",
                "\n",
                "public final class MainActivityPermissionsDispatcher {",
                "  private static final int REQUEST_SHOWCAMERA = 0;",
                "\n",
                "  private static final String[] PERMISSION_SHOWCAMERA = new String[]{\"android.permission.CAMERA\"};",
                "\n",
                "  private MainActivityPermissionsDispatcher() {",
                "  }",
                "\n",
                "  public static void showCameraWithCheck(MainActivity target) {",
                "    if (PermissionUtils.hasSelfPermissions(target, PERMISSION_SHOWCAMERA)) {",
                "      target.showCamera();",
                "    } else {",
                "      if (PermissionUtils.shouldShowRequestPermissionRationale(target, PERMISSION_SHOWCAMERA)) {",
                "        target.showRationaleForCamera();",
                "      }",
                "      ActivityCompat.requestPermissions(target, PERMISSION_SHOWCAMERA, REQUEST_SHOWCAMERA);",
                "    }",
                "  }",
                "\n",
                "  public static void onRequestPermissionsResult(MainActivity target, int requestCode, int[] grantResults) {",
                "    switch (requestCode) {",
                "      case REQUEST_SHOWCAMERA:",
                "      if (PermissionUtils.verifyPermissions(grantResults)) {",
                "        target.showCamera();",
                "      }",
                "      break;",
                "      default:",
                "      break;",
                "    }",
                "  }",
                "}"
        };
    }

    public static class OnePermissionFragment {
        public static final String[] ACTUAL = {
                "package permissions.dispatcher.sample;",
                "import android.Manifest;",
                "import android.app.Fragment;",
                "import android.os.Bundle;",
                "import android.view.Menu;",
                "import android.view.MenuItem;",
                "import permissions.dispatcher.NeedsPermission;",
                "import permissions.dispatcher.RuntimePermissions;",
                "import permissions.dispatcher.ShowsRationale;",
                "@RuntimePermissions",
                "public class MainFragment extends Fragment {",
                "@NeedsPermission(Manifest.permission.CAMERA)",
                "void showCamera() {",
                "}",
                "@ShowsRationale(Manifest.permission.CAMERA)",
                "void showRationaleForCamera() {",
                "}",
                "}"};

        public static final String[] EXPECT = {
                "package permissions.dispatcher.sample;",
                "\n",
                "import android.support.v4.app.ActivityCompat;",
                "import java.lang.String;",
                "import permissions.dispatcher.PermissionUtils;",
                "\n",
                "public final class MainFragmentPermissionsDispatcher {",
                "  private static final int REQUEST_SHOWCAMERA = 0;",
                "\n",
                "  private static final String[] PERMISSION_SHOWCAMERA = new String[]{\"android.permission.CAMERA\"};",
                "\n",
                "  private MainActivityPermissionsDispatcher() {",
                "  }",
                "\n",
                "  public static void showCameraWithCheck(MainFragment target) {",
                "    if (PermissionUtils.hasSelfPermissions(target.getActivity(), PERMISSION_SHOWCAMERA)) {",
                "      target.showCamera();",
                "    } else {",
                "      if (PermissionUtils.shouldShowRequestPermissionRationale(target.getActivity(), PERMISSION_SHOWCAMERA)) {",
                "        target.showRationaleForCamera();",
                "      }",
                "      ActivityCompat.requestPermissions(target.getActivity(), PERMISSION_SHOWCAMERA, REQUEST_SHOWCAMERA);",
                "    }",
                "  }",
                "\n",
                "  public static void onRequestPermissionsResult(MainFragment target, int requestCode, int[] grantResults) {",
                "    switch (requestCode) {",
                "      case REQUEST_SHOWCAMERA:",
                "      if (PermissionUtils.verifyPermissions(grantResults)) {",
                "        target.showCamera();",
                "      }",
                "      break;",
                "      default:",
                "      break;",
                "    }",
                "  }",
                "}"
        };
    }

    public static class TwoPermissions {
        public static final String[] ACTUAL = {
                "package permissions.dispatcher.sample;",
                "import android.Manifest;",
                "import android.app.Activity;",
                "import android.os.Bundle;",
                "import android.view.Menu;",
                "import android.view.MenuItem;",
                "import permissions.dispatcher.NeedsPermission;",
                "import permissions.dispatcher.NeedsPermissions;",
                "import permissions.dispatcher.RuntimePermissions;",
                "import permissions.dispatcher.ShowsRationale;",
                "import permissions.dispatcher.ShowsRationales;",
                "@RuntimePermissions",
                "public class MainActivity extends Activity {",
                "@NeedsPermission(Manifest.permission.CAMERA)",
                "void showCamera() {",
                "}",
                "@NeedsPermissions({Manifest.permission.READ_CONTACTS, Manifest.permission.WRITE_CONTACTS})",
                "void showContact() {",
                "}",
                "@ShowsRationale(Manifest.permission.CAMERA)",
                "void showRationaleForCamera() {",
                "}",
                "@ShowsRationales({Manifest.permission.READ_CONTACTS, Manifest.permission.WRITE_CONTACTS})",
                "void showRationaleForContact() {",
                "}",
                "}"};

        public static final String[] EXPECT = {
                "package permissions.dispatcher.sample;",
                "\n",
                "import android.support.v4.app.ActivityCompat;",
                "import java.lang.String;",
                "import permissions.dispatcher.PermissionUtils;",
                "\n",
                "public final class MainActivityPermissionsDispatcher {",
                "  private static final int REQUEST_SHOWCAMERA = 0;",
                "\n",
                "  private static final String[] PERMISSION_SHOWCAMERA = new String[]{\"android.permission.CAMERA\"};",
                "\n",
                "  private static final int REQUEST_SHOWCONTACT = 1;",
                "\n",
                "  private static final String[] PERMISSION_SHOWCONTACT = new String[]{\"android.permission.READ_CONTACTS\", \"android.permission.WRITE_CONTACTS\"};",
                "\n",
                "  private MainActivityPermissionsDispatcher() {",
                "  }",
                "\n",
                "  public static void showCameraWithCheck(MainActivity target) {",
                "    if (PermissionUtils.hasSelfPermissions(target, PERMISSION_SHOWCAMERA)) {",
                "      target.showCamera();",
                "    } else {",
                "      if (PermissionUtils.shouldShowRequestPermissionRationale(target, PERMISSION_SHOWCAMERA)) {",
                "        target.showRationaleForCamera();",
                "      }",
                "      ActivityCompat.requestPermissions(target, PERMISSION_SHOWCAMERA, REQUEST_SHOWCAMERA);",
                "    }",
                "  }",
                "\n",
                "  public static void showContactWithCheck(MainActivity target) {",
                "    if (PermissionUtils.hasSelfPermissions(target, PERMISSION_SHOWCONTACT)) {",
                "      target.showContact();",
                "    } else {",
                "      if (PermissionUtils.shouldShowRequestPermissionRationale(target, PERMISSION_SHOWCONTACT)) {",
                "        target.showRationaleForContact();",
                "      }",
                "      ActivityCompat.requestPermissions(target, PERMISSION_SHOWCONTACT, REQUEST_SHOWCONTACT);",
                "    }",
                "  }",
                "\n",
                "  public static void onRequestPermissionsResult(MainActivity target, int requestCode, int[] grantResults) {",
                "    switch (requestCode) {",
                "      case REQUEST_SHOWCAMERA:",
                "      if (PermissionUtils.verifyPermissions(grantResults)) {",
                "        target.showCamera();",
                "      }",
                "      break;",
                "      case REQUEST_SHOWCONTACT:",
                "      if (PermissionUtils.verifyPermissions(grantResults)) {",
                "        target.showContact();",
                "      }",
                "      break;",
                "      default:",
                "      break;",
                "    }",
                "  }",
                "}"
        };
    }

    public static class NoShowRationale {
        public static final String[] ACTUAL = {
                "package permissions.dispatcher.sample;",
                "import android.Manifest;",
                "import android.app.Activity;",
                "import android.os.Bundle;",
                "import android.view.Menu;",
                "import android.view.MenuItem;",
                "import permissions.dispatcher.NeedsPermission;",
                "import permissions.dispatcher.NeedsPermissions;",
                "import permissions.dispatcher.RuntimePermissions;",
                "import permissions.dispatcher.ShowsRationale;",
                "@RuntimePermissions",
                "public class MainActivity extends Activity {",
                "@NeedsPermission(Manifest.permission.CAMERA)",
                "void showCamera() {",
                "}",
                "@NeedsPermissions({Manifest.permission.READ_CONTACTS, Manifest.permission.WRITE_CONTACTS})",
                "void showContact() {",
                "}",
                "}"};

        public static final String[] EXPECT = {
                "package permissions.dispatcher.sample;",
                "\n",
                "import android.support.v4.app.ActivityCompat;",
                "import java.lang.String;",
                "import permissions.dispatcher.PermissionUtils;",
                "\n",
                "public final class MainActivityPermissionsDispatcher {",
                "  private static final int REQUEST_SHOWCAMERA = 0;",
                "\n",
                "  private static final String[] PERMISSION_SHOWCAMERA = new String[]{\"android.permission.CAMERA\"};",
                "\n",
                "  private static final int REQUEST_SHOWCONTACT = 1;",
                "\n",
                "  private static final String[] PERMISSION_SHOWCONTACT = new String[]{\"android.permission.READ_CONTACTS\", \"android.permission.WRITE_CONTACTS\"};",
                "\n",
                "  private MainActivityPermissionsDispatcher() {",
                "  }",
                "\n",
                "  public static void showCameraWithCheck(MainActivity target) {",
                "    if (PermissionUtils.hasSelfPermissions(target,PERMISSION_SHOWCAMERA)) {",
                "      target.showCamera();",
                "    } else {",
                "      ActivityCompat.requestPermissions(target, PERMISSION_SHOWCAMERA, REQUEST_SHOWCAMERA);",
                "    }",
                "  }",
                "\n",
                "  public static void showContactWithCheck(MainActivity target) {",
                "    if (PermissionUtils.hasSelfPermissions(target, PERMISSION_SHOWCONTACT)) {",
                "      target.showContact();",
                "    } else {",
                "      ActivityCompat.requestPermissions(target, PERMISSION_SHOWCONTACT, REQUEST_SHOWCONTACT);",
                "    }",
                "  }",
                "\n",
                "  public static void onRequestPermissionsResult(MainActivity target, int requestCode, int[] grantResults) {",
                "    switch (requestCode) {",
                "      case REQUEST_SHOWCAMERA:",
                "      if (PermissionUtils.verifyPermissions(grantResults)) {",
                "        target.showCamera();",
                "      }",
                "      break;",
                "      case REQUEST_SHOWCONTACT:",
                "      if (PermissionUtils.verifyPermissions(grantResults)) {",
                "        target.showContact();",
                "      }",
                "      break;",
                "      default:",
                "      break;",
                "    }",
                "  }",
                "}"
        };
    }

    public static class OnePermissionAndOtherRationale {
        public static final String[] ACTUAL = {
                "package permissions.dispatcher.sample;",
                "import android.Manifest;",
                "import android.app.Activity;",
                "import android.os.Bundle;",
                "import android.view.Menu;",
                "import android.view.MenuItem;",
                "import permissions.dispatcher.NeedsPermission;",
                "import permissions.dispatcher.RuntimePermissions;",
                "import permissions.dispatcher.ShowsRationale;",
                "@RuntimePermissions",
                "public class MainActivity extends Activity {",
                "@NeedsPermission(Manifest.permission.CAMERA)",
                "void showCamera() {",
                "}",
                "@ShowsRationale(Manifest.permission.READ_CONTACTS)",
                "void showRationaleForCamera() {",
                "}",
                "}"};

        public static final String[] EXPECT = {
                "package permissions.dispatcher.sample;",
                "\n",
                "import android.support.v4.app.ActivityCompat;",
                "import java.lang.String;",
                "import permissions.dispatcher.PermissionUtils;",
                "\n",
                "public final class MainActivityPermissionsDispatcher {",
                "  private static final int REQUEST_SHOWCAMERA = 0;",
                "\n",
                "  private static final String[] PERMISSION_SHOWCAMERA = new String[]{\"android.permission.CAMERA\"};",
                "\n",
                "  private MainActivityPermissionsDispatcher() {",
                "  }",
                "\n",
                "  public static void showCameraWithCheck(MainActivity target) {",
                "    if (PermissionUtils.hasSelfPermissions(target, PERMISSION_SHOWCAMERA)) {",
                "      target.showCamera();",
                "    } else {",
                "      ActivityCompat.requestPermissions(target, PERMISSION_SHOWCAMERA, REQUEST_SHOWCAMERA);",
                "    }",
                "  }",
                "\n",
                "  public static void onRequestPermissionsResult(MainActivity target, int requestCode, int[] grantResults) {",
                "    switch (requestCode) {",
                "      case REQUEST_SHOWCAMERA:",
                "      if (PermissionUtils.verifyPermissions(grantResults)) {",
                "        target.showCamera();",
                "      }",
                "      break;",
                "      default:",
                "      break;",
                "    }",
                "  }",
                "}"
        };
    }

    public static class OnePermissionAndOtherRationales {
        public static final String[] ACTUAL = {
                "package permissions.dispatcher.sample;",
                "import android.Manifest;",
                "import android.app.Activity;",
                "import android.os.Bundle;",
                "import android.view.Menu;",
                "import android.view.MenuItem;",
                "import permissions.dispatcher.NeedsPermissions;",
                "import permissions.dispatcher.RuntimePermissions;",
                "import permissions.dispatcher.ShowsRationales;",
                "@RuntimePermissions",
                "public class MainActivity extends Activity {",
                "@NeedsPermissions({Manifest.permission.CAMERA})",
                "void showCamera() {",
                "}",
                "@ShowsRationales({Manifest.permission.READ_CONTACTS})",
                "void showRationaleForCamera() {",
                "}",
                "}"};

        public static final String[] EXPECT = {
                "package permissions.dispatcher.sample;",
                "\n",
                "import android.support.v4.app.ActivityCompat;",
                "import java.lang.String;",
                "import permissions.dispatcher.PermissionUtils;",
                "\n",
                "public final class MainActivityPermissionsDispatcher {",
                "  private static final int REQUEST_SHOWCAMERA = 0;",
                "\n",
                "  private static final String[] PERMISSION_SHOWCAMERA = new String[]{\"android.permission.CAMERA\"};",
                "\n",
                "  private MainActivityPermissionsDispatcher() {",
                "  }",
                "\n",
                "  public static void showCameraWithCheck(MainActivity target) {",
                "    if (PermissionUtils.hasSelfPermissions(target, PERMISSION_SHOWCAMERA)) {",
                "      target.showCamera();",
                "    } else {",
                "      ActivityCompat.requestPermissions(target, PERMISSION_SHOWCAMERA, REQUEST_SHOWCAMERA);",
                "    }",
                "  }",
                "\n",
                "  public static void onRequestPermissionsResult(MainActivity target, int requestCode, int[] grantResults) {",
                "    switch (requestCode) {",
                "      case REQUEST_SHOWCAMERA:",
                "      if (PermissionUtils.verifyPermissions(grantResults)) {",
                "        target.showCamera();",
                "      }",
                "      break;",
                "      default:",
                "      break;",
                "    }",
                "  }",
                "}"
        };
    }

    public static class ZeroPermission {
        public static final String[] ACTUAL = {
                "package permissions.dispatcher.sample;",
                "import android.Manifest;",
                "import android.app.Activity;",
                "import android.os.Bundle;",
                "import android.view.Menu;",
                "import android.view.MenuItem;",
                "import permissions.dispatcher.NeedsPermission;",
                "import permissions.dispatcher.RuntimePermissions;",
                "import permissions.dispatcher.ShowsRationale;",
                "@RuntimePermissions",
                "public class MainActivity extends Activity {",
                "}"};
    }

    public static class WrongClassName {
        public static final String[] ACTUAL = {
                "package permissions.dispatcher.sample;",
                "import android.Manifest;",
                "import android.os.Bundle;",
                "import android.view.Menu;",
                "import android.view.MenuItem;",
                "import permissions.dispatcher.NeedsPermission;",
                "import permissions.dispatcher.RuntimePermissions;",
                "import permissions.dispatcher.ShowsRationale;",
                "@RuntimePermissions",
                "public class MainUtils {",
                "@NeedsPermission(Manifest.permission.CAMERA)",
                "void showCamera() {",
                "}",
                "@ShowsRationale(Manifest.permission.CAMERA)",
                "void showRationaleForCamera() {",
                "}",
                "}"};
    }

    public static class DuplicatedPermission {
        public static final String[] ACTUAL = {
                "package permissions.dispatcher.sample;",
                "import android.Manifest;",
                "import android.app.Activity;",
                "import android.os.Bundle;",
                "import android.view.Menu;",
                "import android.view.MenuItem;",
                "import permissions.dispatcher.NeedsPermission;",
                "import permissions.dispatcher.RuntimePermissions;",
                "import permissions.dispatcher.ShowsRationale;",
                "@RuntimePermissions",
                "public class MainActivity extends Activity {",
                "@NeedsPermission(Manifest.permission.CAMERA)",
                "void showCamera() {",
                "}",
                "@NeedsPermission(Manifest.permission.CAMERA)",
                "void showContact() {",
                "}",
                "}"};
    }

    public static class DuplicatedPermissions {
        public static final String[] ACTUAL = {
                "package permissions.dispatcher.sample;",
                "import android.Manifest;",
                "import android.app.Activity;",
                "import android.os.Bundle;",
                "import android.view.Menu;",
                "import android.view.MenuItem;",
                "import permissions.dispatcher.NeedsPermissions;",
                "import permissions.dispatcher.RuntimePermissions;",
                "import permissions.dispatcher.ShowsRationale;",
                "@RuntimePermissions",
                "public class MainActivity extends Activity {",
                "@NeedsPermissions({Manifest.permission.CAMERA})",
                "void showCamera() {",
                "}",
                "@NeedsPermissions({Manifest.permission.CAMERA})",
                "void showContact() {",
                "}",
                "}"};
    }

    public static class DuplicatedRationale {
        public static final String[] ACTUAL = {
                "package permissions.dispatcher.sample;",
                "import android.Manifest;",
                "import android.app.Activity;",
                "import android.os.Bundle;",
                "import android.view.Menu;",
                "import android.view.MenuItem;",
                "import permissions.dispatcher.NeedsPermission;",
                "import permissions.dispatcher.RuntimePermissions;",
                "import permissions.dispatcher.ShowsRationale;",
                "@RuntimePermissions",
                "public class MainActivity extends Activity {",
                "@NeedsPermission(Manifest.permission.CAMERA)",
                "void showCamera() {",
                "}",
                "@ShowsRationale(Manifest.permission.READ_CONTACTS)",
                "void showContact() {",
                "}",
                "@ShowsRationale(Manifest.permission.READ_CONTACTS)",
                "void showRationaleForContact() {",
                "}",
                "}"};
    }

    public static class DuplicatedRationales {
        public static final String[] ACTUAL = {
                "package permissions.dispatcher.sample;",
                "import android.Manifest;",
                "import android.app.Activity;",
                "import android.os.Bundle;",
                "import android.view.Menu;",
                "import android.view.MenuItem;",
                "import permissions.dispatcher.NeedsPermissions;",
                "import permissions.dispatcher.RuntimePermissions;",
                "import permissions.dispatcher.ShowsRationales;",
                "@RuntimePermissions",
                "public class MainActivity extends Activity {",
                "@NeedsPermissions({Manifest.permission.CAMERA})",
                "void showCamera() {",
                "}",
                "@ShowsRationales({Manifest.permission.READ_CONTACTS})",
                "void showContact() {",
                "}",
                "@ShowsRationales({Manifest.permission.READ_CONTACTS})",
                "void showRationaleForContact() {",
                "}",
                "}"};
    }

    public static class NeedsPermissionIsPrivate {
        public static final String[] ACTUAL = {
                "package permissions.dispatcher.sample;",
                "import android.Manifest;",
                "import android.app.Activity;",
                "import android.os.Bundle;",
                "import android.view.Menu;",
                "import android.view.MenuItem;",
                "import permissions.dispatcher.NeedsPermission;",
                "import permissions.dispatcher.RuntimePermissions;",
                "import permissions.dispatcher.ShowsRationale;",
                "@RuntimePermissions",
                "public class MainActivity extends Activity {",
                "@NeedsPermission(Manifest.permission.CAMERA)",
                "private void showCamera() {",
                "}",
                "}"};
    }

    public static class NeedsPermissionsIsPrivate {
        public static final String[] ACTUAL = {
                "package permissions.dispatcher.sample;",
                "import android.Manifest;",
                "import android.app.Activity;",
                "import android.os.Bundle;",
                "import android.view.Menu;",
                "import android.view.MenuItem;",
                "import permissions.dispatcher.NeedsPermissions;",
                "import permissions.dispatcher.RuntimePermissions;",
                "import permissions.dispatcher.ShowsRationale;",
                "@RuntimePermissions",
                "public class MainActivity extends Activity {",
                "@NeedsPermissions({Manifest.permission.CAMERA})",
                "private void showCamera() {",
                "}",
                "}"};
    }

    public static class ShowsRationaleIsPrivate {
        public static final String[] ACTUAL = {
                "package permissions.dispatcher.sample;",
                "import android.Manifest;",
                "import android.app.Activity;",
                "import android.os.Bundle;",
                "import android.view.Menu;",
                "import android.view.MenuItem;",
                "import permissions.dispatcher.NeedsPermission;",
                "import permissions.dispatcher.RuntimePermissions;",
                "import permissions.dispatcher.ShowsRationale;",
                "@RuntimePermissions",
                "public class MainActivity extends Activity {",
                "@NeedsPermission(Manifest.permission.CAMERA)",
                "private void showCamera() {",
                "}",
                "@ShowsRationale(Manifest.permission.CAMERA)",
                "void showRationaleForCamera() {",
                "}",
                "}"};
    }

    public static class ShowsRationalesIsPrivate {
        public static final String[] ACTUAL = {
                "package permissions.dispatcher.sample;",
                "import android.Manifest;",
                "import android.app.Activity;",
                "import android.os.Bundle;",
                "import android.view.Menu;",
                "import android.view.MenuItem;",
                "import permissions.dispatcher.NeedsPermissions;",
                "import permissions.dispatcher.RuntimePermissions;",
                "import permissions.dispatcher.ShowsRationales;",
                "@RuntimePermissions",
                "public class MainActivity extends Activity {",
                "@NeedsPermissions({Manifest.permission.CAMERA})",
                "private void showCamera() {",
                "}",
                "@ShowsRationales({Manifest.permission.CAMERA})",
                "void showRationaleForCamera() {",
                "}",
                "}"};
    }

    public static class OneDeniedPermission {
        public static final String[] ACTUAL = {
                "package permissions.dispatcher.sample;",
                "import android.Manifest;",
                "import android.app.Activity;",
                "import android.os.Bundle;",
                "import android.view.Menu;",
                "import android.view.MenuItem;",
                "import permissions.dispatcher.NeedsPermission;",
                "import permissions.dispatcher.RuntimePermissions;",
                "import permissions.dispatcher.DeniedPermission;",
                "@RuntimePermissions",
                "public class MainActivity extends Activity {",
                "@NeedsPermission(Manifest.permission.CAMERA)",
                "void showCamera() {",
                "}",
                "@DeniedPermission(Manifest.permission.CAMERA)",
                "void onCameraPermissionDenied() {",
                "}",
                "}"};

        public static final String[] EXPECT = {
                "package permissions.dispatcher.sample;",
                "\n",
                "import android.support.v4.app.ActivityCompat;",
                "import java.lang.String;",
                "import permissions.dispatcher.PermissionUtils;",
                "\n",
                "public final class MainActivityPermissionsDispatcher {",
                "  private static final int REQUEST_SHOWCAMERA = 0;",
                "\n",
                "  private static final String[] PERMISSION_SHOWCAMERA = new String[]{\"android.permission.CAMERA\"};",
                "\n",
                "  private MainActivityPermissionsDispatcher() {",
                "  }",
                "\n",
                "  public static void showCameraWithCheck(MainActivity target) {",
                "    if (PermissionUtils.hasSelfPermissions(target, PERMISSION_SHOWCAMERA)) {",
                "      target.showCamera();",
                "    } else {",
                "      ActivityCompat.requestPermissions(target, PERMISSION_SHOWCAMERA, REQUEST_SHOWCAMERA);",
                "    }",
                "  }",
                "\n",
                "  public static void onRequestPermissionsResult(MainActivity target, int requestCode, int[] grantResults) {",
                "    switch (requestCode) {",
                "      case REQUEST_SHOWCAMERA:",
                "      if (PermissionUtils.verifyPermissions(grantResults)) {",
                "        target.showCamera();",
                "      } else {",
                "        target.onCameraPermissionDenied();",
                "      }",
                "      break;",
                "      default:",
                "      break;",
                "    }",
                "  }",
                "}"
        };
    }

    public static class OneDeniedPermissions {
        public static final String[] ACTUAL = {
                "package permissions.dispatcher.sample;",
                "import android.Manifest;",
                "import android.app.Activity;",
                "import android.os.Bundle;",
                "import android.view.Menu;",
                "import android.view.MenuItem;",
                "import permissions.dispatcher.NeedsPermissions;",
                "import permissions.dispatcher.RuntimePermissions;",
                "import permissions.dispatcher.DeniedPermissions;",
                "@RuntimePermissions",
                "public class MainActivity extends Activity {",
                "@NeedsPermissions({Manifest.permission.CAMERA})",
                "void showCamera() {",
                "}",
                "@DeniedPermissions({Manifest.permission.CAMERA})",
                "void onCameraPermissionDenied() {",
                "}",
                "}"};

        public static final String[] EXPECT = {
                "package permissions.dispatcher.sample;",
                "\n",
                "import android.support.v4.app.ActivityCompat;",
                "import java.lang.String;",
                "import permissions.dispatcher.PermissionUtils;",
                "\n",
                "public final class MainActivityPermissionsDispatcher {",
                "  private static final int REQUEST_SHOWCAMERA = 0;",
                "\n",
                "  private static final String[] PERMISSION_SHOWCAMERA = new String[]{\"android.permission.CAMERA\"};",
                "\n",
                "  private MainActivityPermissionsDispatcher() {",
                "  }",
                "\n",
                "  public static void showCameraWithCheck(MainActivity target) {",
                "    if (PermissionUtils.hasSelfPermissions(target, PERMISSION_SHOWCAMERA)) {",
                "      target.showCamera();",
                "    } else {",
                "      ActivityCompat.requestPermissions(target, PERMISSION_SHOWCAMERA, REQUEST_SHOWCAMERA);",
                "    }",
                "  }",
                "\n",
                "  public static void onRequestPermissionsResult(MainActivity target, int requestCode, int[] grantResults) {",
                "    switch (requestCode) {",
                "      case REQUEST_SHOWCAMERA:",
                "      if (PermissionUtils.verifyPermissions(grantResults)) {",
                "        target.showCamera();",
                "      } else {",
                "        target.onCameraPermissionDenied();",
                "      }",
                "      break;",
                "      default:",
                "      break;",
                "    }",
                "  }",
                "}"
        };
    }

    public static class TwoDeniedPermission {
        public static final String[] ACTUAL = {
                "package permissions.dispatcher.sample;",
                "import android.Manifest;",
                "import android.app.Activity;",
                "import android.os.Bundle;",
                "import android.view.Menu;",
                "import android.view.MenuItem;",
                "import permissions.dispatcher.NeedsPermission;",
                "import permissions.dispatcher.RuntimePermissions;",
                "import permissions.dispatcher.DeniedPermission;",
                "@RuntimePermissions",
                "public class MainActivity extends Activity {",
                "@NeedsPermission(Manifest.permission.CAMERA)",
                "void showCamera() {",
                "}",
                "@NeedsPermission(Manifest.permission.READ_CONTACTS)",
                "void accessContacts() {",
                "}",
                "@DeniedPermission(Manifest.permission.CAMERA)",
                "void onCameraPermissionDenied() {",
                "}",
                "@DeniedPermission(Manifest.permission.READ_CONTACTS)",
                "void onAccessContactsDenied() {",
                "}",
                "}"};

        public static final String[] EXPECT = {
                "package permissions.dispatcher.sample;",
                "\n",
                "import android.support.v4.app.ActivityCompat;",
                "import java.lang.String;",
                "import permissions.dispatcher.PermissionUtils;",
                "\n",
                "public final class MainActivityPermissionsDispatcher {",
                "  private static final int REQUEST_SHOWCAMERA = 0;",
                "\n",
                "  private static final String[] PERMISSION_SHOWCAMERA = new String[]{\"android.permission.CAMERA\"};",
                "\n",
                "  private static final int REQUEST_ACCESSCONTACTS = 1;",
                "\n",
                "  private static final String[] PERMISSION_ACCESSCONTACTS = new String[]{\"android.permission.READ_CONTACTS\"};",
                "\n",
                "  private MainActivityPermissionsDispatcher() {",
                "  }",
                "\n",
                "  public static void showCameraWithCheck(MainActivity target) {",
                "    if (PermissionUtils.hasSelfPermissions(target, PERMISSION_SHOWCAMERA)) {",
                "      target.showCamera();",
                "    } else {",
                "      ActivityCompat.requestPermissions(target, PERMISSION_SHOWCAMERA, REQUEST_SHOWCAMERA);",
                "    }",
                "  }",
                "\n",
                "  public static void accessContactsWithCheck(MainActivity target) {",
                "    if (PermissionUtils.hasSelfPermissions(target, PERMISSION_ACCESSCONTACTS)) {",
                "      target.accessContacts();",
                "    } else {",
                "      ActivityCompat.requestPermissions(target, PERMISSION_ACCESSCONTACTS, REQUEST_ACCESSCONTACTS);",
                "    }",
                "  }",
                "\n",
                "  public static void onRequestPermissionsResult(MainActivity target, int requestCode, int[] grantResults) {",
                "    switch (requestCode) {",
                "      case REQUEST_SHOWCAMERA:",
                "      if (PermissionUtils.verifyPermissions(grantResults)) {",
                "        target.showCamera();",
                "      } else {",
                "        target.onCameraPermissionDenied();",
                "      }",
                "      break;",
                "      case REQUEST_ACCESSCONTACTS:",
                "      if (PermissionUtils.verifyPermissions(grantResults)) {",
                "        target.accessContacts();",
                "      } else {",
                "        target.onAccessContactsDenied();",
                "      }",
                "      break;",
                "      default:",
                "      break;",
                "    }",
                "  }",
                "}"
        };
    }

    public static class DeniedPermissionWithoutNeedsPermission {
        public static final String[] ACTUAL = {
                "package permissions.dispatcher.sample;",
                "import android.Manifest;",
                "import android.app.Activity;",
                "import android.os.Bundle;",
                "import android.view.Menu;",
                "import android.view.MenuItem;",
                "import permissions.dispatcher.NeedsPermission;",
                "import permissions.dispatcher.RuntimePermissions;",
                "import permissions.dispatcher.DeniedPermission;",
                "@RuntimePermissions",
                "public class MainActivity extends Activity {",
                "@NeedsPermission(Manifest.permission.READ_CONTACTS)",
                "void accessContacts() {",
                "}",
                "@DeniedPermission(Manifest.permission.CAMERA)",
                "void onCameraPermissionDenied() {",
                "}",
                "}"};
    }

    public static class DuplicatedDeniedPermission {
        public static final String[] ACTUAL = {
                "package permissions.dispatcher.sample;",
                "import android.Manifest;",
                "import android.app.Activity;",
                "import android.os.Bundle;",
                "import android.view.Menu;",
                "import android.view.MenuItem;",
                "import permissions.dispatcher.NeedsPermission;",
                "import permissions.dispatcher.RuntimePermissions;",
                "import permissions.dispatcher.DeniedPermission;",
                "import permissions.dispatcher.ShowsRationale;",
                "@RuntimePermissions",
                "public class MainActivity extends Activity {",
                "@NeedsPermission(Manifest.permission.CAMERA)",
                "void showCamera() {",
                "}",
                "@DeniedPermission(Manifest.permission.CAMERA)",
                "void onCameraPermissionDenied() {",
                "}",
                "@DeniedPermission(Manifest.permission.CAMERA)",
                "void onReadContactsDenied() {",
                "}",
                "}"};
    }

    public static class DuplicatedDeniedPermissions {
        public static final String[] ACTUAL = {
                "package permissions.dispatcher.sample;",
                "import android.Manifest;",
                "import android.app.Activity;",
                "import android.os.Bundle;",
                "import android.view.Menu;",
                "import android.view.MenuItem;",
                "import permissions.dispatcher.NeedsPermissions;",
                "import permissions.dispatcher.RuntimePermissions;",
                "import permissions.dispatcher.DeniedPermissions;",
                "import permissions.dispatcher.ShowsRationale;",
                "@RuntimePermissions",
                "public class MainActivity extends Activity {",
                "@NeedsPermissions({Manifest.permission.CAMERA})",
                "void showCamera() {",
                "}",
                "@DeniedPermissions({Manifest.permission.CAMERA})",
                "void onCameraPermissionDenied() {",
                "}",
                "@DeniedPermissions({Manifest.permission.CAMERA})",
                "void onReadContactsDenied() {",
                "}",
                "}"};
    }

    public static class DeniedPermissionIsPrivate {
        public static final String[] ACTUAL = {
                "package permissions.dispatcher.sample;",
                "import android.Manifest;",
                "import android.app.Activity;",
                "import android.os.Bundle;",
                "import android.view.Menu;",
                "import android.view.MenuItem;",
                "import permissions.dispatcher.NeedsPermission;",
                "import permissions.dispatcher.RuntimePermissions;",
                "import permissions.dispatcher.DeniedPermission;",
                "@RuntimePermissions",
                "public class MainActivity extends Activity {",
                "@NeedsPermission(Manifest.permission.CAMERA)",
                "void showCamera() {",
                "}",
                "@DeniedPermission(Manifest.permission.CAMERA)",
                "private void onCameraPermissionDenied() {",
                "}",
                "}"};
    }

    public static class DeniedPermissionsIsPrivate {
        public static final String[] ACTUAL = {
                "package permissions.dispatcher.sample;",
                "import android.Manifest;",
                "import android.app.Activity;",
                "import android.os.Bundle;",
                "import android.view.Menu;",
                "import android.view.MenuItem;",
                "import permissions.dispatcher.NeedsPermissions;",
                "import permissions.dispatcher.RuntimePermissions;",
                "import permissions.dispatcher.DeniedPermissions;",
                "@RuntimePermissions",
                "public class MainActivity extends Activity {",
                "@NeedsPermissions({Manifest.permission.CAMERA})",
                "void showCamera() {",
                "}",
                "@DeniedPermissions({Manifest.permission.CAMERA})",
                "private void onCameraPermissionDenied() {",
                "}",
                "}"};
    }
}
